@@ -1,5 +1,5 @@
 /**
- * Copyright 2013-2016 Sylvain Cadilhac (NetFishers)
+ * Copyright 2013-2019 Sylvain Cadilhac (NetFishers)
  * 
  * This file is part of Netshot.
  * 
@@ -21,7 +21,7 @@ var Info = {
 	name: "CiscoIOS12",
 	description: "Cisco IOS and IOS-XE",
 	author: "NetFishers",
-	version: "1.6.1"
+	version: "1.6.3"
 };
 
 var Config = {
@@ -396,6 +396,16 @@ function snapshot(cli, device, config, debug) {
 			device.set("family", "Cisco VG200");
 			device.set("networkClass", "UNKNOWN");
 		}
+		else if (system.match(/cisco C9200/)) {
+			device.set("family", "Cisco Catalyst 9200");
+		}
+		else if (system.match(/cisco C9300/)) {
+			device.set("family", "Cisco Catalyst 9300");
+		}
+		else if (system.match(/cisco C9500/)) {
+			device.set("family", "Cisco Catalyst 9500");
+			device.set("networkClass", "SWITCHROUTER");
+		}
 	}
 	var configRegister = showVersion.match(/^Configuration register is (.*)/m);
 	if (configRegister != null) {
@@ -529,7 +539,7 @@ function analyzeTrap(trap, debug) {
 }
 
 function snmpAutoDiscover(sysObjectID, sysDesc) {
-	if (sysObjectID.substring(0, 16) == "1.3.6.1.4.1.9.1."
+	if (sysObjectID.match(/^1\.3\.6\.1\.4\.1\.9\.1(\..*|$)/)
 		&& sysDesc.match(/^Cisco (IOS|Internetwork Operating System) Software.*/)) {
 		return true;
 	}
