@@ -8,6 +8,8 @@ define([
 		
 		initialize: function(models, options) {
 			this.domains = options.domains;
+			this.deviceGroups = options.deviceGroups;
+			this.policies = options.policies;
 		},
 
 		url: function() {
@@ -18,6 +20,16 @@ define([
 					params.push("domain=" + domain);
 				});
 			}
+			if (this.deviceGroups) {
+				_.forEach(this.deviceGroups, function(group) {
+					params.push("group=" + group);
+				});
+			}
+			if (this.policies) {
+				_.forEach(this.policies, function(policy) {
+					params.push("policy=" + policy);
+				});
+			}
 			if (params.length) {
 				url += "?" + params.join("&");
 			}
